@@ -1,12 +1,17 @@
 from http import HTTPStatus
-from typing import Any, Dict, Optional, Union
+from typing import Any, Dict, List, Optional, Union, cast
 
 import httpx
 
-from ...client import Client
-from ...models.data_point_response_base import DataPointResponseBase
+from ...client import AuthenticatedClient, Client
+from ...types import Response, UNSET
+from ... import errors
+
+from typing import Dict
 from ...models.problem_details import ProblemDetails
-from ...types import Response
+from ...models.data_point_response_base import DataPointResponseBase
+from typing import cast
+
 
 
 def _get_kwargs(
@@ -15,45 +20,77 @@ def _get_kwargs(
     version: int,
     *,
     client: Client,
+
 ) -> Dict[str, Any]:
     url = "{}/DataPoint/workspace/{workspaceId}/dataPoint/{dataPointId}/version/{version}".format(
-        client.base_url, workspaceId=workspace_id, dataPointId=data_point_id, version=version
-    )
+        client.base_url,workspaceId=workspace_id,dataPointId=data_point_id,version=version)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
+    
+
+    
+
+    
+
+    
+
+    
+
     return {
-        "method": "get",
+	    "method": "get",
         "url": url,
         "headers": headers,
         "cookies": cookies,
         "timeout": client.get_timeout(),
+        "follow_redirects": client.follow_redirects,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[Union[DataPointResponseBase, ProblemDetails]]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Union[DataPointResponseBase, ProblemDetails]]:
     if response.status_code == HTTPStatus.OK:
         response_200 = DataPointResponseBase.from_dict(response.json())
 
+
+
         return response_200
+    if response.status_code == HTTPStatus.BAD_REQUEST:
+        response_400 = ProblemDetails.from_dict(response.json())
+
+
+
+        return response_400
     if response.status_code == HTTPStatus.UNAUTHORIZED:
         response_401 = ProblemDetails.from_dict(response.json())
 
+
+
         return response_401
     if response.status_code == HTTPStatus.FORBIDDEN:
         response_403 = ProblemDetails.from_dict(response.json())
 
+
+
         return response_403
-    return None
+    if response.status_code == HTTPStatus.NOT_FOUND:
+        response_404 = ProblemDetails.from_dict(response.json())
 
 
-def _build_response(*, response: httpx.Response) -> Response[Union[DataPointResponseBase, ProblemDetails]]:
+
+        return response_404
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
+
+
+def _build_response(*, client: Client, response: httpx.Response) -> Response[Union[DataPointResponseBase, ProblemDetails]]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -63,22 +100,29 @@ def sync_detailed(
     version: int,
     *,
     client: Client,
+
 ) -> Response[Union[DataPointResponseBase, ProblemDetails]]:
-    """
+    """ 
     Args:
         workspace_id (str):
         data_point_id (str):
         version (int):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Union[DataPointResponseBase, ProblemDetails]]
-    """
+     """
+
 
     kwargs = _get_kwargs(
         workspace_id=workspace_id,
-        data_point_id=data_point_id,
-        version=version,
-        client=client,
+data_point_id=data_point_id,
+version=version,
+client=client,
+
     )
 
     response = httpx.request(
@@ -86,8 +130,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
-
+    return _build_response(client=client, response=response)
 
 def sync(
     workspace_id: str,
@@ -95,24 +138,30 @@ def sync(
     version: int,
     *,
     client: Client,
+
 ) -> Optional[Union[DataPointResponseBase, ProblemDetails]]:
-    """
+    """ 
     Args:
         workspace_id (str):
         data_point_id (str):
         version (int):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[Union[DataPointResponseBase, ProblemDetails]]
-    """
+        Union[DataPointResponseBase, ProblemDetails]
+     """
+
 
     return sync_detailed(
         workspace_id=workspace_id,
-        data_point_id=data_point_id,
-        version=version,
-        client=client,
-    ).parsed
+data_point_id=data_point_id,
+version=version,
+client=client,
 
+    ).parsed
 
 async def asyncio_detailed(
     workspace_id: str,
@@ -120,29 +169,37 @@ async def asyncio_detailed(
     version: int,
     *,
     client: Client,
+
 ) -> Response[Union[DataPointResponseBase, ProblemDetails]]:
-    """
+    """ 
     Args:
         workspace_id (str):
         data_point_id (str):
         version (int):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Union[DataPointResponseBase, ProblemDetails]]
-    """
+     """
+
 
     kwargs = _get_kwargs(
         workspace_id=workspace_id,
-        data_point_id=data_point_id,
-        version=version,
-        client=client,
+data_point_id=data_point_id,
+version=version,
+client=client,
+
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
-
-    return _build_response(response=response)
+        response = await _client.request(
+            **kwargs
+        )
 
+    return _build_response(client=client, response=response)
 
 async def asyncio(
     workspace_id: str,
@@ -150,22 +207,27 @@ async def asyncio(
     version: int,
     *,
     client: Client,
+
 ) -> Optional[Union[DataPointResponseBase, ProblemDetails]]:
-    """
+    """ 
     Args:
         workspace_id (str):
         data_point_id (str):
         version (int):
 
-    Returns:
-        Response[Union[DataPointResponseBase, ProblemDetails]]
-    """
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    return (
-        await asyncio_detailed(
-            workspace_id=workspace_id,
-            data_point_id=data_point_id,
-            version=version,
-            client=client,
-        )
-    ).parsed
+    Returns:
+        Union[DataPointResponseBase, ProblemDetails]
+     """
+
+
+    return (await asyncio_detailed(
+        workspace_id=workspace_id,
+data_point_id=data_point_id,
+version=version,
+client=client,
+
+    )).parsed
