@@ -1,12 +1,17 @@
 from http import HTTPStatus
-from typing import Any, Dict, Optional, Union, cast
+from typing import Any, Dict, List, Optional, Union, cast
 
 import httpx
 
-from ...client import Client
+from ...client import AuthenticatedClient, Client
+from ...types import Response, UNSET
+from ... import errors
+
+from typing import Dict
 from ...models.data_point_request import DataPointRequest
 from ...models.problem_details import ProblemDetails
-from ...types import Response
+from typing import cast
+
 
 
 def _get_kwargs(
@@ -15,51 +20,71 @@ def _get_kwargs(
     *,
     client: Client,
     json_body: DataPointRequest,
+
 ) -> Dict[str, Any]:
     url = "{}/DataPoint/workspace/{workspaceId}/dataPoint/{dataPointId}".format(
-        client.base_url, workspaceId=workspace_id, dataPointId=data_point_id
-    )
+        client.base_url,workspaceId=workspace_id,dataPointId=data_point_id)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
+    
+
+    
+
+    
+
     json_json_body = json_body.to_dict()
 
+
+
+    
+
     return {
-        "method": "patch",
+	    "method": "patch",
         "url": url,
         "headers": headers,
         "cookies": cookies,
         "timeout": client.get_timeout(),
+        "follow_redirects": client.follow_redirects,
         "json": json_json_body,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, ProblemDetails]]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Union[Any, ProblemDetails]]:
     if response.status_code == HTTPStatus.ACCEPTED:
         response_202 = cast(Any, None)
         return response_202
     if response.status_code == HTTPStatus.BAD_REQUEST:
         response_400 = ProblemDetails.from_dict(response.json())
 
+
+
         return response_400
     if response.status_code == HTTPStatus.UNAUTHORIZED:
         response_401 = ProblemDetails.from_dict(response.json())
 
+
+
         return response_401
     if response.status_code == HTTPStatus.FORBIDDEN:
         response_403 = ProblemDetails.from_dict(response.json())
 
+
+
         return response_403
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[Union[Any, ProblemDetails]]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[Union[Any, ProblemDetails]]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -69,22 +94,29 @@ def sync_detailed(
     *,
     client: Client,
     json_body: DataPointRequest,
+
 ) -> Response[Union[Any, ProblemDetails]]:
-    """
+    """ 
     Args:
         workspace_id (str):
         data_point_id (str):
         json_body (DataPointRequest):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Union[Any, ProblemDetails]]
-    """
+     """
+
 
     kwargs = _get_kwargs(
         workspace_id=workspace_id,
-        data_point_id=data_point_id,
-        client=client,
-        json_body=json_body,
+data_point_id=data_point_id,
+client=client,
+json_body=json_body,
+
     )
 
     response = httpx.request(
@@ -92,8 +124,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
-
+    return _build_response(client=client, response=response)
 
 def sync(
     workspace_id: str,
@@ -101,24 +132,30 @@ def sync(
     *,
     client: Client,
     json_body: DataPointRequest,
+
 ) -> Optional[Union[Any, ProblemDetails]]:
-    """
+    """ 
     Args:
         workspace_id (str):
         data_point_id (str):
         json_body (DataPointRequest):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[Union[Any, ProblemDetails]]
-    """
+        Union[Any, ProblemDetails]
+     """
+
 
     return sync_detailed(
         workspace_id=workspace_id,
-        data_point_id=data_point_id,
-        client=client,
-        json_body=json_body,
-    ).parsed
+data_point_id=data_point_id,
+client=client,
+json_body=json_body,
 
+    ).parsed
 
 async def asyncio_detailed(
     workspace_id: str,
@@ -126,29 +163,37 @@ async def asyncio_detailed(
     *,
     client: Client,
     json_body: DataPointRequest,
+
 ) -> Response[Union[Any, ProblemDetails]]:
-    """
+    """ 
     Args:
         workspace_id (str):
         data_point_id (str):
         json_body (DataPointRequest):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Union[Any, ProblemDetails]]
-    """
+     """
+
 
     kwargs = _get_kwargs(
         workspace_id=workspace_id,
-        data_point_id=data_point_id,
-        client=client,
-        json_body=json_body,
+data_point_id=data_point_id,
+client=client,
+json_body=json_body,
+
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
-
-    return _build_response(response=response)
+        response = await _client.request(
+            **kwargs
+        )
 
+    return _build_response(client=client, response=response)
 
 async def asyncio(
     workspace_id: str,
@@ -156,22 +201,27 @@ async def asyncio(
     *,
     client: Client,
     json_body: DataPointRequest,
+
 ) -> Optional[Union[Any, ProblemDetails]]:
-    """
+    """ 
     Args:
         workspace_id (str):
         data_point_id (str):
         json_body (DataPointRequest):
 
-    Returns:
-        Response[Union[Any, ProblemDetails]]
-    """
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    return (
-        await asyncio_detailed(
-            workspace_id=workspace_id,
-            data_point_id=data_point_id,
-            client=client,
-            json_body=json_body,
-        )
-    ).parsed
+    Returns:
+        Union[Any, ProblemDetails]
+     """
+
+
+    return (await asyncio_detailed(
+        workspace_id=workspace_id,
+data_point_id=data_point_id,
+client=client,
+json_body=json_body,
+
+    )).parsed
