@@ -1,23 +1,35 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING
+
+from typing import List
+
 
 import attr
 
 from ..types import UNSET, Unset
 
+from ..types import UNSET, Unset
+from typing import Union
+from typing import Optional
+
+
+
+
+
+
 T = TypeVar("T", bound="ConstantDataPointData")
 
 
 @attr.s(auto_attribs=True)
 class ConstantDataPointData:
-    """
-    Attributes:
-        discriminator (str):
-        status (Union[Unset, None, str]):
-        error_message (Union[Unset, None, str]):
-        unit (Union[Unset, None, str]):
-        number_of_entries (Union[Unset, int]):
-        value (Union[Unset, float]):
-    """
+    """ 
+        Attributes:
+            discriminator (str):
+            status (Union[Unset, None, str]):
+            error_message (Union[Unset, None, str]):
+            unit (Union[Unset, None, str]):
+            number_of_entries (Union[Unset, int]):
+            value (Union[Unset, float]):
+     """
 
     discriminator: str
     status: Union[Unset, None, str] = UNSET
@@ -27,6 +39,7 @@ class ConstantDataPointData:
     value: Union[Unset, float] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
+
     def to_dict(self) -> Dict[str, Any]:
         discriminator = self.discriminator
         status = self.status
@@ -37,11 +50,9 @@ class ConstantDataPointData:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update(
-            {
-                "discriminator": discriminator,
-            }
-        )
+        field_dict.update({
+            "discriminator": discriminator,
+        })
         if status is not UNSET:
             field_dict["status"] = status
         if error_message is not UNSET:
@@ -55,6 +66,8 @@ class ConstantDataPointData:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
