@@ -1,22 +1,32 @@
-from typing import Any, Dict, Type, TypeVar, Union
+from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING
+
 
 import attr
 
 from ..types import UNSET, Unset
 
+from ..types import UNSET, Unset
+from typing import Union
+from typing import Optional
+
+
+
+
+
+
 T = TypeVar("T", bound="DataPointDataBase")
 
 
 @attr.s(auto_attribs=True)
 class DataPointDataBase:
-    """
-    Attributes:
-        discriminator (str):
-        status (Union[Unset, None, str]):
-        error_message (Union[Unset, None, str]):
-        unit (Union[Unset, None, str]):
-        number_of_entries (Union[Unset, int]):
-    """
+    """ 
+        Attributes:
+            discriminator (str):
+            status (Union[Unset, None, str]):
+            error_message (Union[Unset, None, str]):
+            unit (Union[Unset, None, str]):
+            number_of_entries (Union[Unset, int]):
+     """
 
     discriminator: str
     status: Union[Unset, None, str] = UNSET
@@ -24,6 +34,7 @@ class DataPointDataBase:
     unit: Union[Unset, None, str] = UNSET
     number_of_entries: Union[Unset, int] = UNSET
 
+
     def to_dict(self) -> Dict[str, Any]:
         discriminator = self.discriminator
         status = self.status
@@ -32,11 +43,9 @@ class DataPointDataBase:
         number_of_entries = self.number_of_entries
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update(
-            {
-                "discriminator": discriminator,
-            }
-        )
+        field_dict.update({
+            "discriminator": discriminator,
+        })
         if status is not UNSET:
             field_dict["status"] = status
         if error_message is not UNSET:
@@ -48,6 +57,8 @@ class DataPointDataBase:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
@@ -70,3 +81,4 @@ class DataPointDataBase:
         )
 
         return data_point_data_base
+
