@@ -1,74 +1,88 @@
-import datetime
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING
+
+from typing import List
+
 
 import attr
-from dateutil.parser import isoparse
 
 from ..types import UNSET, Unset
 
+from typing import Optional
+from typing import cast
+from ..types import UNSET, Unset
+from dateutil.parser import isoparse
+import datetime
+from typing import Union
+
+
+
+
+
+
 T = TypeVar("T", bound="DayDataByHourTransfer")
 
 
 @attr.s(auto_attribs=True)
 class DayDataByHourTransfer:
-    """
-    Attributes:
-        discriminator (str):
-        date (Union[Unset, None, datetime.datetime]):
-        h0 (Union[Unset, float]):
-        h1 (Union[Unset, float]):
-        h2 (Union[Unset, float]):
-        h3 (Union[Unset, float]):
-        h4 (Union[Unset, float]):
-        h5 (Union[Unset, float]):
-        h6 (Union[Unset, float]):
-        h7 (Union[Unset, float]):
-        h8 (Union[Unset, float]):
-        h9 (Union[Unset, float]):
-        h10 (Union[Unset, float]):
-        h11 (Union[Unset, float]):
-        h12 (Union[Unset, float]):
-        h13 (Union[Unset, float]):
-        h14 (Union[Unset, float]):
-        h15 (Union[Unset, float]):
-        h16 (Union[Unset, float]):
-        h17 (Union[Unset, float]):
-        h18 (Union[Unset, float]):
-        h19 (Union[Unset, float]):
-        h20 (Union[Unset, float]):
-        h21 (Union[Unset, float]):
-        h22 (Union[Unset, float]):
-        h23 (Union[Unset, float]):
-    """
+    """ 
+        Attributes:
+            discriminator (str):
+            date (Union[Unset, None, datetime.datetime]):
+            h0 (Union[Unset, None, float]):
+            h1 (Union[Unset, None, float]):
+            h2 (Union[Unset, None, float]):
+            h3 (Union[Unset, None, float]):
+            h4 (Union[Unset, None, float]):
+            h5 (Union[Unset, None, float]):
+            h6 (Union[Unset, None, float]):
+            h7 (Union[Unset, None, float]):
+            h8 (Union[Unset, None, float]):
+            h9 (Union[Unset, None, float]):
+            h10 (Union[Unset, None, float]):
+            h11 (Union[Unset, None, float]):
+            h12 (Union[Unset, None, float]):
+            h13 (Union[Unset, None, float]):
+            h14 (Union[Unset, None, float]):
+            h15 (Union[Unset, None, float]):
+            h16 (Union[Unset, None, float]):
+            h17 (Union[Unset, None, float]):
+            h18 (Union[Unset, None, float]):
+            h19 (Union[Unset, None, float]):
+            h20 (Union[Unset, None, float]):
+            h21 (Union[Unset, None, float]):
+            h22 (Union[Unset, None, float]):
+            h23 (Union[Unset, None, float]):
+     """
 
     discriminator: str
     date: Union[Unset, None, datetime.datetime] = UNSET
-    h0: Union[Unset, float] = UNSET
-    h1: Union[Unset, float] = UNSET
-    h2: Union[Unset, float] = UNSET
-    h3: Union[Unset, float] = UNSET
-    h4: Union[Unset, float] = UNSET
-    h5: Union[Unset, float] = UNSET
-    h6: Union[Unset, float] = UNSET
-    h7: Union[Unset, float] = UNSET
-    h8: Union[Unset, float] = UNSET
-    h9: Union[Unset, float] = UNSET
-    h10: Union[Unset, float] = UNSET
-    h11: Union[Unset, float] = UNSET
-    h12: Union[Unset, float] = UNSET
-    h13: Union[Unset, float] = UNSET
-    h14: Union[Unset, float] = UNSET
-    h15: Union[Unset, float] = UNSET
-    h16: Union[Unset, float] = UNSET
-    h17: Union[Unset, float] = UNSET
-    h18: Union[Unset, float] = UNSET
-    h19: Union[Unset, float] = UNSET
-    h20: Union[Unset, float] = UNSET
-    h21: Union[Unset, float] = UNSET
-    h22: Union[Unset, float] = UNSET
-    h23: Union[Unset, float] = UNSET
+    h0: Union[Unset, None, float] = UNSET
+    h1: Union[Unset, None, float] = UNSET
+    h2: Union[Unset, None, float] = UNSET
+    h3: Union[Unset, None, float] = UNSET
+    h4: Union[Unset, None, float] = UNSET
+    h5: Union[Unset, None, float] = UNSET
+    h6: Union[Unset, None, float] = UNSET
+    h7: Union[Unset, None, float] = UNSET
+    h8: Union[Unset, None, float] = UNSET
+    h9: Union[Unset, None, float] = UNSET
+    h10: Union[Unset, None, float] = UNSET
+    h11: Union[Unset, None, float] = UNSET
+    h12: Union[Unset, None, float] = UNSET
+    h13: Union[Unset, None, float] = UNSET
+    h14: Union[Unset, None, float] = UNSET
+    h15: Union[Unset, None, float] = UNSET
+    h16: Union[Unset, None, float] = UNSET
+    h17: Union[Unset, None, float] = UNSET
+    h18: Union[Unset, None, float] = UNSET
+    h19: Union[Unset, None, float] = UNSET
+    h20: Union[Unset, None, float] = UNSET
+    h21: Union[Unset, None, float] = UNSET
+    h22: Union[Unset, None, float] = UNSET
+    h23: Union[Unset, None, float] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
+
     def to_dict(self) -> Dict[str, Any]:
         discriminator = self.discriminator
         date: Union[Unset, None, str] = UNSET
@@ -102,11 +116,9 @@ class DayDataByHourTransfer:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update(
-            {
-                "discriminator": discriminator,
-            }
-        )
+        field_dict.update({
+            "discriminator": discriminator,
+        })
         if date is not UNSET:
             field_dict["date"] = date
         if h0 is not UNSET:
@@ -160,6 +172,8 @@ class DayDataByHourTransfer:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
@@ -169,11 +183,14 @@ class DayDataByHourTransfer:
         date: Union[Unset, None, datetime.datetime]
         if _date is None:
             date = None
-        elif isinstance(_date, Unset):
+        elif isinstance(_date,  Unset):
             date = UNSET
         else:
             date = isoparse(_date)
 
+
+
+
         h0 = d.pop("h0", UNSET)
 
         h1 = d.pop("h1", UNSET)
