@@ -1,13 +1,25 @@
-import datetime
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING
+
+from typing import List
+
 
 import attr
-from dateutil.parser import isoparse
 
 from ..types import UNSET, Unset
 
+from typing import Dict
+from typing import Optional
+from typing import cast
+from ..types import UNSET, Unset
+from dateutil.parser import isoparse
+import datetime
+from typing import Union
+
 if TYPE_CHECKING:
-    from ..models.day_data_by_hour_transfer import DayDataByHourTransfer
+  from ..models.day_data_base_transfer import DayDataBaseTransfer
+
+
+
 
 
 T = TypeVar("T", bound="DayPeriodDataPointData")
@@ -15,27 +27,29 @@ T = TypeVar("T", bound="DayPeriodDataPointData")
 
 @attr.s(auto_attribs=True)
 class DayPeriodDataPointData:
-    """
-    Attributes:
-        discriminator (str):
-        status (Union[Unset, None, str]):
-        error_message (Union[Unset, None, str]):
-        unit (Union[Unset, None, str]):
-        number_of_entries (Union[Unset, int]):
-        day_data (Union[Unset, None, DayDataByHourTransfer]):
-        date (Union[Unset, None, datetime.datetime]):
-    """
+    """ 
+        Attributes:
+            discriminator (str):
+            status (Union[Unset, None, str]):
+            error_message (Union[Unset, None, str]):
+            unit (Union[Unset, None, str]):
+            number_of_entries (Union[Unset, int]):
+            day_data (Union[Unset, None, DayDataBaseTransfer]):
+            date (Union[Unset, None, datetime.datetime]):
+     """
 
     discriminator: str
     status: Union[Unset, None, str] = UNSET
     error_message: Union[Unset, None, str] = UNSET
     unit: Union[Unset, None, str] = UNSET
     number_of_entries: Union[Unset, int] = UNSET
-    day_data: Union[Unset, None, "DayDataByHourTransfer"] = UNSET
+    day_data: Union[Unset, None, 'DayDataBaseTransfer'] = UNSET
     date: Union[Unset, None, datetime.datetime] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
+
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.day_data_base_transfer import DayDataBaseTransfer
         discriminator = self.discriminator
         status = self.status
         error_message = self.error_message
@@ -49,13 +63,12 @@ class DayPeriodDataPointData:
         if not isinstance(self.date, Unset):
             date = self.date.isoformat() if self.date else None
 
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update(
-            {
-                "discriminator": discriminator,
-            }
-        )
+        field_dict.update({
+            "discriminator": discriminator,
+        })
         if status is not UNSET:
             field_dict["status"] = status
         if error_message is not UNSET:
@@ -71,10 +84,11 @@ class DayPeriodDataPointData:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.day_data_by_hour_transfer import DayDataByHourTransfer
-
+        from ..models.day_data_base_transfer import DayDataBaseTransfer
         d = src_dict.copy()
         discriminator = d.pop("discriminator")
 
@@ -87,23 +101,29 @@ class DayPeriodDataPointData:
         number_of_entries = d.pop("numberOfEntries", UNSET)
 
         _day_data = d.pop("dayData", UNSET)
-        day_data: Union[Unset, None, DayDataByHourTransfer]
+        day_data: Union[Unset, None, DayDataBaseTransfer]
         if _day_data is None:
             day_data = None
-        elif isinstance(_day_data, Unset):
+        elif isinstance(_day_data,  Unset):
             day_data = UNSET
         else:
-            day_data = DayDataByHourTransfer.from_dict(_day_data)
+            day_data = DayDataBaseTransfer.from_dict(_day_data)
+
+
+
 
         _date = d.pop("date", UNSET)
         date: Union[Unset, None, datetime.datetime]
         if _date is None:
             date = None
-        elif isinstance(_date, Unset):
+        elif isinstance(_date,  Unset):
             date = UNSET
         else:
             date = isoparse(_date)
 
+
+
+
         day_period_data_point_data = cls(
             discriminator=discriminator,
             status=status,
