@@ -1,14 +1,26 @@
-import datetime
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING
+
+from typing import List
+
 
 import attr
-from dateutil.parser import isoparse
 
 from ..types import UNSET, Unset
 
+from typing import Dict
+from typing import Optional
+from typing import cast
+from ..types import UNSET, Unset
+from dateutil.parser import isoparse
+import datetime
+from typing import Union
+
 if TYPE_CHECKING:
-    from ..models.day_data_by_hour_transfer import DayDataByHourTransfer
-    from ..models.gnista_unit_response import GnistaUnitResponse
+  from ..models.day_data_base_transfer import DayDataBaseTransfer
+  from ..models.gnista_unit_response import GnistaUnitResponse
+
+
+
 
 
 T = TypeVar("T", bound="GetDayPeriodResponse")
@@ -16,21 +28,24 @@ T = TypeVar("T", bound="GetDayPeriodResponse")
 
 @attr.s(auto_attribs=True)
 class GetDayPeriodResponse:
-    """
-    Attributes:
-        discriminator (str):
-        day_data (Union[Unset, None, DayDataByHourTransfer]):
-        date (Union[Unset, None, datetime.datetime]):
-        unit (Union[Unset, None, GnistaUnitResponse]):
-    """
+    """ 
+        Attributes:
+            discriminator (str):
+            day_data (Union[Unset, None, DayDataBaseTransfer]):
+            date (Union[Unset, None, datetime.datetime]):
+            unit (Union[Unset, None, GnistaUnitResponse]):
+     """
 
     discriminator: str
-    day_data: Union[Unset, None, "DayDataByHourTransfer"] = UNSET
+    day_data: Union[Unset, None, 'DayDataBaseTransfer'] = UNSET
     date: Union[Unset, None, datetime.datetime] = UNSET
-    unit: Union[Unset, None, "GnistaUnitResponse"] = UNSET
+    unit: Union[Unset, None, 'GnistaUnitResponse'] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
+
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.day_data_base_transfer import DayDataBaseTransfer
+        from ..models.gnista_unit_response import GnistaUnitResponse
         discriminator = self.discriminator
         day_data: Union[Unset, None, Dict[str, Any]] = UNSET
         if not isinstance(self.day_data, Unset):
@@ -44,13 +59,12 @@ class GetDayPeriodResponse:
         if not isinstance(self.unit, Unset):
             unit = self.unit.to_dict() if self.unit else None
 
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update(
-            {
-                "discriminator": discriminator,
-            }
-        )
+        field_dict.update({
+            "discriminator": discriminator,
+        })
         if day_data is not UNSET:
             field_dict["dayData"] = day_data
         if date is not UNSET:
@@ -60,41 +74,51 @@ class GetDayPeriodResponse:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.day_data_by_hour_transfer import DayDataByHourTransfer
+        from ..models.day_data_base_transfer import DayDataBaseTransfer
         from ..models.gnista_unit_response import GnistaUnitResponse
-
         d = src_dict.copy()
         discriminator = d.pop("discriminator")
 
         _day_data = d.pop("dayData", UNSET)
-        day_data: Union[Unset, None, DayDataByHourTransfer]
+        day_data: Union[Unset, None, DayDataBaseTransfer]
         if _day_data is None:
             day_data = None
-        elif isinstance(_day_data, Unset):
+        elif isinstance(_day_data,  Unset):
             day_data = UNSET
         else:
-            day_data = DayDataByHourTransfer.from_dict(_day_data)
+            day_data = DayDataBaseTransfer.from_dict(_day_data)
+
+
+
 
         _date = d.pop("date", UNSET)
         date: Union[Unset, None, datetime.datetime]
         if _date is None:
             date = None
-        elif isinstance(_date, Unset):
+        elif isinstance(_date,  Unset):
             date = UNSET
         else:
             date = isoparse(_date)
 
+
+
+
         _unit = d.pop("unit", UNSET)
         unit: Union[Unset, None, GnistaUnitResponse]
         if _unit is None:
             unit = None
-        elif isinstance(_unit, Unset):
+        elif isinstance(_unit,  Unset):
             unit = UNSET
         else:
             unit = GnistaUnitResponse.from_dict(_unit)
 
+
+
+
         get_day_period_response = cls(
             discriminator=discriminator,
             day_data=day_data,
