@@ -1,12 +1,24 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING
+
+from typing import List
+
 
 import attr
 
 from ..types import UNSET, Unset
 
+from typing import Dict
+from typing import Optional
+from typing import cast
+from ..types import UNSET, Unset
+from typing import Union
+
 if TYPE_CHECKING:
-    from ..models.gnista_unit_response import GnistaUnitResponse
-    from ..models.week_data_transfere import WeekDataTransfere
+  from ..models.week_data_transfere import WeekDataTransfere
+  from ..models.gnista_unit_response import GnistaUnitResponse
+
+
+
 
 
 T = TypeVar("T", bound="GetWeekPeriodResponse")
@@ -14,19 +26,22 @@ T = TypeVar("T", bound="GetWeekPeriodResponse")
 
 @attr.s(auto_attribs=True)
 class GetWeekPeriodResponse:
-    """
-    Attributes:
-        discriminator (str):
-        week_data (Union[Unset, None, WeekDataTransfere]):
-        unit (Union[Unset, None, GnistaUnitResponse]):
-    """
+    """ 
+        Attributes:
+            discriminator (str):
+            week_data (Union[Unset, None, WeekDataTransfere]):
+            unit (Union[Unset, None, GnistaUnitResponse]):
+     """
 
     discriminator: str
-    week_data: Union[Unset, None, "WeekDataTransfere"] = UNSET
-    unit: Union[Unset, None, "GnistaUnitResponse"] = UNSET
+    week_data: Union[Unset, None, 'WeekDataTransfere'] = UNSET
+    unit: Union[Unset, None, 'GnistaUnitResponse'] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
+
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.week_data_transfere import WeekDataTransfere
+        from ..models.gnista_unit_response import GnistaUnitResponse
         discriminator = self.discriminator
         week_data: Union[Unset, None, Dict[str, Any]] = UNSET
         if not isinstance(self.week_data, Unset):
@@ -36,13 +51,12 @@ class GetWeekPeriodResponse:
         if not isinstance(self.unit, Unset):
             unit = self.unit.to_dict() if self.unit else None
 
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update(
-            {
-                "discriminator": discriminator,
-            }
-        )
+        field_dict.update({
+            "discriminator": discriminator,
+        })
         if week_data is not UNSET:
             field_dict["weekData"] = week_data
         if unit is not UNSET:
@@ -50,11 +64,12 @@ class GetWeekPeriodResponse:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.gnista_unit_response import GnistaUnitResponse
         from ..models.week_data_transfere import WeekDataTransfere
-
+        from ..models.gnista_unit_response import GnistaUnitResponse
         d = src_dict.copy()
         discriminator = d.pop("discriminator")
 
@@ -62,20 +77,26 @@ class GetWeekPeriodResponse:
         week_data: Union[Unset, None, WeekDataTransfere]
         if _week_data is None:
             week_data = None
-        elif isinstance(_week_data, Unset):
+        elif isinstance(_week_data,  Unset):
             week_data = UNSET
         else:
             week_data = WeekDataTransfere.from_dict(_week_data)
 
+
+
+
         _unit = d.pop("unit", UNSET)
         unit: Union[Unset, None, GnistaUnitResponse]
         if _unit is None:
             unit = None
-        elif isinstance(_unit, Unset):
+        elif isinstance(_unit,  Unset):
             unit = UNSET
         else:
             unit = GnistaUnitResponse.from_dict(_unit)
 
+
+
+
         get_week_period_response = cls(
             discriminator=discriminator,
             week_data=week_data,
