@@ -1,11 +1,23 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING
+
+from typing import List
+
 
 import attr
 
 from ..types import UNSET, Unset
 
+from typing import Dict
+from typing import Optional
+from typing import cast
+from ..types import UNSET, Unset
+from typing import Union
+
 if TYPE_CHECKING:
-    from ..models.problem_details_extensions import ProblemDetailsExtensions
+  from ..models.problem_details_extensions import ProblemDetailsExtensions
+
+
+
 
 
 T = TypeVar("T", bound="ProblemDetails")
@@ -13,25 +25,27 @@ T = TypeVar("T", bound="ProblemDetails")
 
 @attr.s(auto_attribs=True)
 class ProblemDetails:
-    """
-    Attributes:
-        type (Union[Unset, None, str]):
-        title (Union[Unset, None, str]):
-        status (Union[Unset, None, int]):
-        detail (Union[Unset, None, str]):
-        instance (Union[Unset, None, str]):
-        extensions (Union[Unset, ProblemDetailsExtensions]):
-    """
+    """ 
+        Attributes:
+            type (Union[Unset, None, str]):
+            title (Union[Unset, None, str]):
+            status (Union[Unset, None, int]):
+            detail (Union[Unset, None, str]):
+            instance (Union[Unset, None, str]):
+            extensions (Union[Unset, ProblemDetailsExtensions]):
+     """
 
     type: Union[Unset, None, str] = UNSET
     title: Union[Unset, None, str] = UNSET
     status: Union[Unset, None, int] = UNSET
     detail: Union[Unset, None, str] = UNSET
     instance: Union[Unset, None, str] = UNSET
-    extensions: Union[Unset, "ProblemDetailsExtensions"] = UNSET
+    extensions: Union[Unset, 'ProblemDetailsExtensions'] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
+
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.problem_details_extensions import ProblemDetailsExtensions
         type = self.type
         title = self.title
         status = self.status
@@ -41,9 +55,11 @@ class ProblemDetails:
         if not isinstance(self.extensions, Unset):
             extensions = self.extensions.to_dict()
 
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        field_dict.update({
+        })
         if type is not UNSET:
             field_dict["type"] = type
         if title is not UNSET:
@@ -59,10 +75,11 @@ class ProblemDetails:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.problem_details_extensions import ProblemDetailsExtensions
-
         d = src_dict.copy()
         type = d.pop("type", UNSET)
 
@@ -76,11 +93,14 @@ class ProblemDetails:
 
         _extensions = d.pop("extensions", UNSET)
         extensions: Union[Unset, ProblemDetailsExtensions]
-        if isinstance(_extensions, Unset):
+        if isinstance(_extensions,  Unset):
             extensions = UNSET
         else:
             extensions = ProblemDetailsExtensions.from_dict(_extensions)
 
+
+
+
         problem_details = cls(
             type=type,
             title=title,
@@ -90,6 +110,7 @@ class ProblemDetails:
             extensions=extensions,
         )
 
+
         problem_details.additional_properties = d
         return problem_details
 
