@@ -1,28 +1,46 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING
+
+from typing import List
+
 
 import attr
 
+from ..types import UNSET, Unset
+
+
+
+
+
+
+
 T = TypeVar("T", bound="SubSeriesRequestValues")
 
 
 @attr.s(auto_attribs=True)
 class SubSeriesRequestValues:
-    """ """
+    """ 
+     """
 
     additional_properties: Dict[str, float] = attr.ib(init=False, factory=dict)
 
-    def to_dict(self) -> Dict[str, Any]:
 
+    def to_dict(self) -> Dict[str, Any]:
+        
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        field_dict.update({
+        })
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        sub_series_request_values = cls()
+        sub_series_request_values = cls(
+        )
+
 
         sub_series_request_values.additional_properties = d
         return sub_series_request_values
