@@ -1,11 +1,21 @@
-from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union
+from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING
+
 
 import attr
 
 from ..types import UNSET, Unset
 
+from typing import Dict
+from typing import Optional
+from typing import cast
+from ..types import UNSET, Unset
+from typing import Union
+
 if TYPE_CHECKING:
-    from ..models.week_data_transfere import WeekDataTransfere
+  from ..models.week_data_transfere import WeekDataTransfere
+
+
+
 
 
 T = TypeVar("T", bound="UpdateWeekPeriodRequest")
@@ -13,18 +23,20 @@ T = TypeVar("T", bound="UpdateWeekPeriodRequest")
 
 @attr.s(auto_attribs=True)
 class UpdateWeekPeriodRequest:
-    """
-    Attributes:
-        execution_id (Union[Unset, None, str]):
-        week_data (Union[Unset, None, WeekDataTransfere]):
-        unit (Union[Unset, None, str]):
-    """
+    """ 
+        Attributes:
+            execution_id (Union[Unset, None, str]):
+            week_data (Union[Unset, None, WeekDataTransfere]):
+            unit (Union[Unset, None, str]):
+     """
 
     execution_id: Union[Unset, None, str] = UNSET
-    week_data: Union[Unset, None, "WeekDataTransfere"] = UNSET
+    week_data: Union[Unset, None, 'WeekDataTransfere'] = UNSET
     unit: Union[Unset, None, str] = UNSET
 
+
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.week_data_transfere import WeekDataTransfere
         execution_id = self.execution_id
         week_data: Union[Unset, None, Dict[str, Any]] = UNSET
         if not isinstance(self.week_data, Unset):
@@ -33,7 +45,8 @@ class UpdateWeekPeriodRequest:
         unit = self.unit
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update({})
+        field_dict.update({
+        })
         if execution_id is not UNSET:
             field_dict["executionId"] = execution_id
         if week_data is not UNSET:
@@ -43,10 +56,11 @@ class UpdateWeekPeriodRequest:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.week_data_transfere import WeekDataTransfere
-
         d = src_dict.copy()
         execution_id = d.pop("executionId", UNSET)
 
@@ -54,11 +68,14 @@ class UpdateWeekPeriodRequest:
         week_data: Union[Unset, None, WeekDataTransfere]
         if _week_data is None:
             week_data = None
-        elif isinstance(_week_data, Unset):
+        elif isinstance(_week_data,  Unset):
             week_data = UNSET
         else:
             week_data = WeekDataTransfere.from_dict(_week_data)
 
+
+
+
         unit = d.pop("unit", UNSET)
 
         update_week_period_request = cls(
@@ -68,3 +85,4 @@ class UpdateWeekPeriodRequest:
         )
 
         return update_week_period_request
+
