@@ -1,11 +1,23 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING
+
+from typing import List
+
 
 import attr
 
 from ..types import UNSET, Unset
 
+from typing import Dict
+from typing import Optional
+from typing import cast
+from ..types import UNSET, Unset
+from typing import Union
+
 if TYPE_CHECKING:
-    from ..models.day_data_by_hour_transfer import DayDataByHourTransfer
+  from ..models.day_data_base_transfer import DayDataBaseTransfer
+
+
+
 
 
 T = TypeVar("T", bound="WeekDataTransfere")
@@ -13,29 +25,31 @@ T = TypeVar("T", bound="WeekDataTransfere")
 
 @attr.s(auto_attribs=True)
 class WeekDataTransfere:
-    """
-    Attributes:
-        discriminator (str):
-        monday_data (Union[Unset, None, DayDataByHourTransfer]):
-        tuesday_data (Union[Unset, None, DayDataByHourTransfer]):
-        wednesday_data (Union[Unset, None, DayDataByHourTransfer]):
-        thursday_data (Union[Unset, None, DayDataByHourTransfer]):
-        friday_data (Union[Unset, None, DayDataByHourTransfer]):
-        saturday_data (Union[Unset, None, DayDataByHourTransfer]):
-        sunday_data (Union[Unset, None, DayDataByHourTransfer]):
-    """
+    """ 
+        Attributes:
+            discriminator (str):
+            monday_data (Union[Unset, None, DayDataBaseTransfer]):
+            tuesday_data (Union[Unset, None, DayDataBaseTransfer]):
+            wednesday_data (Union[Unset, None, DayDataBaseTransfer]):
+            thursday_data (Union[Unset, None, DayDataBaseTransfer]):
+            friday_data (Union[Unset, None, DayDataBaseTransfer]):
+            saturday_data (Union[Unset, None, DayDataBaseTransfer]):
+            sunday_data (Union[Unset, None, DayDataBaseTransfer]):
+     """
 
     discriminator: str
-    monday_data: Union[Unset, None, "DayDataByHourTransfer"] = UNSET
-    tuesday_data: Union[Unset, None, "DayDataByHourTransfer"] = UNSET
-    wednesday_data: Union[Unset, None, "DayDataByHourTransfer"] = UNSET
-    thursday_data: Union[Unset, None, "DayDataByHourTransfer"] = UNSET
-    friday_data: Union[Unset, None, "DayDataByHourTransfer"] = UNSET
-    saturday_data: Union[Unset, None, "DayDataByHourTransfer"] = UNSET
-    sunday_data: Union[Unset, None, "DayDataByHourTransfer"] = UNSET
+    monday_data: Union[Unset, None, 'DayDataBaseTransfer'] = UNSET
+    tuesday_data: Union[Unset, None, 'DayDataBaseTransfer'] = UNSET
+    wednesday_data: Union[Unset, None, 'DayDataBaseTransfer'] = UNSET
+    thursday_data: Union[Unset, None, 'DayDataBaseTransfer'] = UNSET
+    friday_data: Union[Unset, None, 'DayDataBaseTransfer'] = UNSET
+    saturday_data: Union[Unset, None, 'DayDataBaseTransfer'] = UNSET
+    sunday_data: Union[Unset, None, 'DayDataBaseTransfer'] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
+
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.day_data_base_transfer import DayDataBaseTransfer
         discriminator = self.discriminator
         monday_data: Union[Unset, None, Dict[str, Any]] = UNSET
         if not isinstance(self.monday_data, Unset):
@@ -65,13 +79,12 @@ class WeekDataTransfere:
         if not isinstance(self.sunday_data, Unset):
             sunday_data = self.sunday_data.to_dict() if self.sunday_data else None
 
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update(
-            {
-                "discriminator": discriminator,
-            }
-        )
+        field_dict.update({
+            "discriminator": discriminator,
+        })
         if monday_data is not UNSET:
             field_dict["mondayData"] = monday_data
         if tuesday_data is not UNSET:
@@ -89,75 +102,97 @@ class WeekDataTransfere:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.day_data_by_hour_transfer import DayDataByHourTransfer
-
+        from ..models.day_data_base_transfer import DayDataBaseTransfer
         d = src_dict.copy()
         discriminator = d.pop("discriminator")
 
         _monday_data = d.pop("mondayData", UNSET)
-        monday_data: Union[Unset, None, DayDataByHourTransfer]
+        monday_data: Union[Unset, None, DayDataBaseTransfer]
         if _monday_data is None:
             monday_data = None
-        elif isinstance(_monday_data, Unset):
+        elif isinstance(_monday_data,  Unset):
             monday_data = UNSET
         else:
-            monday_data = DayDataByHourTransfer.from_dict(_monday_data)
+            monday_data = DayDataBaseTransfer.from_dict(_monday_data)
+
+
+
 
         _tuesday_data = d.pop("tuesdayData", UNSET)
-        tuesday_data: Union[Unset, None, DayDataByHourTransfer]
+        tuesday_data: Union[Unset, None, DayDataBaseTransfer]
         if _tuesday_data is None:
             tuesday_data = None
-        elif isinstance(_tuesday_data, Unset):
+        elif isinstance(_tuesday_data,  Unset):
             tuesday_data = UNSET
         else:
-            tuesday_data = DayDataByHourTransfer.from_dict(_tuesday_data)
+            tuesday_data = DayDataBaseTransfer.from_dict(_tuesday_data)
+
+
+
 
         _wednesday_data = d.pop("wednesdayData", UNSET)
-        wednesday_data: Union[Unset, None, DayDataByHourTransfer]
+        wednesday_data: Union[Unset, None, DayDataBaseTransfer]
         if _wednesday_data is None:
             wednesday_data = None
-        elif isinstance(_wednesday_data, Unset):
+        elif isinstance(_wednesday_data,  Unset):
             wednesday_data = UNSET
         else:
-            wednesday_data = DayDataByHourTransfer.from_dict(_wednesday_data)
+            wednesday_data = DayDataBaseTransfer.from_dict(_wednesday_data)
+
+
+
 
         _thursday_data = d.pop("thursdayData", UNSET)
-        thursday_data: Union[Unset, None, DayDataByHourTransfer]
+        thursday_data: Union[Unset, None, DayDataBaseTransfer]
         if _thursday_data is None:
             thursday_data = None
-        elif isinstance(_thursday_data, Unset):
+        elif isinstance(_thursday_data,  Unset):
             thursday_data = UNSET
         else:
-            thursday_data = DayDataByHourTransfer.from_dict(_thursday_data)
+            thursday_data = DayDataBaseTransfer.from_dict(_thursday_data)
+
+
+
 
         _friday_data = d.pop("fridayData", UNSET)
-        friday_data: Union[Unset, None, DayDataByHourTransfer]
+        friday_data: Union[Unset, None, DayDataBaseTransfer]
         if _friday_data is None:
             friday_data = None
-        elif isinstance(_friday_data, Unset):
+        elif isinstance(_friday_data,  Unset):
             friday_data = UNSET
         else:
-            friday_data = DayDataByHourTransfer.from_dict(_friday_data)
+            friday_data = DayDataBaseTransfer.from_dict(_friday_data)
+
+
+
 
         _saturday_data = d.pop("saturdayData", UNSET)
-        saturday_data: Union[Unset, None, DayDataByHourTransfer]
+        saturday_data: Union[Unset, None, DayDataBaseTransfer]
         if _saturday_data is None:
             saturday_data = None
-        elif isinstance(_saturday_data, Unset):
+        elif isinstance(_saturday_data,  Unset):
             saturday_data = UNSET
         else:
-            saturday_data = DayDataByHourTransfer.from_dict(_saturday_data)
+            saturday_data = DayDataBaseTransfer.from_dict(_saturday_data)
+
+
+
 
         _sunday_data = d.pop("sundayData", UNSET)
-        sunday_data: Union[Unset, None, DayDataByHourTransfer]
+        sunday_data: Union[Unset, None, DayDataBaseTransfer]
         if _sunday_data is None:
             sunday_data = None
-        elif isinstance(_sunday_data, Unset):
+        elif isinstance(_sunday_data,  Unset):
             sunday_data = UNSET
         else:
-            sunday_data = DayDataByHourTransfer.from_dict(_sunday_data)
+            sunday_data = DayDataBaseTransfer.from_dict(_sunday_data)
+
+
+
 
         week_data_transfere = cls(
             discriminator=discriminator,
