@@ -1,11 +1,23 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING
+
+from typing import List
+
 
 import attr
 
 from ..types import UNSET, Unset
 
+from typing import Dict
+from typing import Optional
+from typing import cast
+from ..types import UNSET, Unset
+from typing import Union
+
 if TYPE_CHECKING:
-    from ..models.week_data_transfere import WeekDataTransfere
+  from ..models.week_data_transfere import WeekDataTransfere
+
+
+
 
 
 T = TypeVar("T", bound="WeekPeriodDataPointData")
@@ -13,25 +25,27 @@ T = TypeVar("T", bound="WeekPeriodDataPointData")
 
 @attr.s(auto_attribs=True)
 class WeekPeriodDataPointData:
-    """
-    Attributes:
-        discriminator (str):
-        status (Union[Unset, None, str]):
-        error_message (Union[Unset, None, str]):
-        unit (Union[Unset, None, str]):
-        number_of_entries (Union[Unset, int]):
-        week_data (Union[Unset, None, WeekDataTransfere]):
-    """
+    """ 
+        Attributes:
+            discriminator (str):
+            status (Union[Unset, None, str]):
+            error_message (Union[Unset, None, str]):
+            unit (Union[Unset, None, str]):
+            number_of_entries (Union[Unset, int]):
+            week_data (Union[Unset, None, WeekDataTransfere]):
+     """
 
     discriminator: str
     status: Union[Unset, None, str] = UNSET
     error_message: Union[Unset, None, str] = UNSET
     unit: Union[Unset, None, str] = UNSET
     number_of_entries: Union[Unset, int] = UNSET
-    week_data: Union[Unset, None, "WeekDataTransfere"] = UNSET
+    week_data: Union[Unset, None, 'WeekDataTransfere'] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
+
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.week_data_transfere import WeekDataTransfere
         discriminator = self.discriminator
         status = self.status
         error_message = self.error_message
@@ -41,13 +55,12 @@ class WeekPeriodDataPointData:
         if not isinstance(self.week_data, Unset):
             week_data = self.week_data.to_dict() if self.week_data else None
 
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update(
-            {
-                "discriminator": discriminator,
-            }
-        )
+        field_dict.update({
+            "discriminator": discriminator,
+        })
         if status is not UNSET:
             field_dict["status"] = status
         if error_message is not UNSET:
@@ -61,10 +74,11 @@ class WeekPeriodDataPointData:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.week_data_transfere import WeekDataTransfere
-
         d = src_dict.copy()
         discriminator = d.pop("discriminator")
 
@@ -80,11 +94,14 @@ class WeekPeriodDataPointData:
         week_data: Union[Unset, None, WeekDataTransfere]
         if _week_data is None:
             week_data = None
-        elif isinstance(_week_data, Unset):
+        elif isinstance(_week_data,  Unset):
             week_data = UNSET
         else:
             week_data = WeekDataTransfere.from_dict(_week_data)
 
+
+
+
         week_period_data_point_data = cls(
             discriminator=discriminator,
             status=status,
