@@ -1,9 +1,14 @@
+"""Nista Library
+
+A client library for accessing nista.io
+"""
+
 import logging
 import sys
 
 import structlog
 
-from .nista_connetion import KeyringNistaConnection, NistaConnection, StaticTokenNistaConnection
+from .nista_connetion import KeyringNistaConnection, NistaConnection, StaticTokenNistaConnection, ReferenceTokenNistaConnection
 from .nista_credential_manager import NistaCredentialManager
 from .nista_data_point import NistaDataPoint
 from .nista_data_points import NistaDataPoints
