@@ -1,3 +1,8 @@
+"""Nista Connection
+
+Contains all connections possible to nista.io
+"""
+
 import datetime
 import webbrowser
 from typing import Optional
@@ -14,6 +19,11 @@ log = get_logger()
 
 # pylint: disable=too-many-instance-attributes
 class NistaConnection:
+    """
+    Base class to open connection to nista.io
+    :scope: the list of scopes to be requested from the Authentication service
+    """
+
     scope = ["data-api"]
 
     # pylint: disable=too-many-arguments
@@ -27,6 +37,16 @@ class NistaConnection:
         client_secret: Optional[str] = None,
         verify_ssl=True,
     ):
+        """Create NistaConnection
+        :param workspace_id: The ID of the workspace to establish connection
+        :param base_url: "https://app.nista.io" if left None
+        :param datapoint_base_url: "/api/datapoint" if left None
+        :param authentication_base_url: "/api/authentication" if left None
+        :param client_id: username for an optional login with OAuth2.0 Client/Secret Authentication
+        :param client_secret: secret for an optional login with OAuth2.0 Client/Secret Authentication
+        :param verify_ssl: define if the https connection will be checked for security
+        """
+
         if base_url is None:
             base_url = "https://app.nista.io"
 
@@ -55,6 +75,10 @@ class NistaConnection:
         return self.base_url
 
     def get_access_token(self) -> str:
+        """
+        starts authentication or uses refresh tokens to generate an OAuth2.0 Access Token, used for further interaction.
+        :raise ValueError: If token can not be generated.
+        """
         if self.refresh_token is None:
             # pylint: disable=E1128
             self.refresh_token = self._load_refresh_token()
@@ -102,7 +126,7 @@ class NistaConnection:
             self._create_tokens_code_flow()
 
         if self.access_token is None:
-            raise Exception("No Token available")
+            raise ValueError("No Token available")
 
         return self.access_token
 
@@ -188,9 +212,20 @@ class NistaConnection:
 
 
 class StaticTokenNistaConnection(NistaConnection):
+    """Connection class that uses a static token string to establish connections
+    :refresh_token: the token to be used for connecting with nista.io
+    """
+
     def __init__(
         self, workspace_id: str, base_url: Optional[str] = None, refresh_token: Optional[str] = None, verify_ssl=True
     ):
+        """
+        :param workspace_id: The ID of the workspace to establish connection
+        :param base_url: "https://app.nista.io" if left None
+        :param refresh_token: the token to be used for connecting with nista.io
+        :param verify_ssl: define if the https connection will be checked for security
+        """
+
         super().__init__(workspace_id=workspace_id, base_url=base_url, verify_ssl=verify_ssl)
         self.refresh_token = refresh_token
 
@@ -201,7 +236,44 @@ class StaticTokenNistaConnection(NistaConnection):
         return self.refresh_token
 
 
+class ReferenceTokenNistaConnection(NistaConnection):
+    """Connection class that uses a static token string to establish connections
+    :reference_token: the token (PAT) to be used for connecting with nista.io
+    """
+    def __init__(
+        self,
+        workspace_id: str,
+        reference_token: str,
+        base_url: Optional[str] = None,
+        verify_ssl=True,
+    ):
+        """
+        :param workspace_id: The ID of the workspace to establish connection
+        :param reference_token: the token to be used for connecting with nista.io
+        :param base_url: "https://app.nista.io" if left None
+        :param verify_ssl: define if the https connection will be checked for security
+        """
+        super().__init__(
+            workspace_id=workspace_id, base_url=base_url, verify_ssl=verify_ssl
+        )
+        self.reference_token = reference_token
+
+    def _store_refresh_token(self, refresh_token: str):
+        pass
+
+    def _load_refresh_token(self) -> Optional[str]:
+        return self.refresh_token
+
+    def get_access_token(self) -> str:
+        return self.reference_token
+
+
 class KeyringNistaConnection(NistaConnection):
+    """OAuth2.0 Connection which stores received access tokens in a local Keyring.
+    :enable_store_refresh_token: switch storage of refreshtoken on/off, in order to just keep access token for a limited period of time
+    :service_name: the keyring service name to be used to store access tokens
+    """
+
     # pylint: disable=too-many-arguments
     def __init__(
         self,
@@ -213,6 +285,15 @@ class KeyringNistaConnection(NistaConnection):
         client_secret: Optional[str] = None,
         verify_ssl=True,
     ):
+        """
+        :param workspace_id: The ID of the workspace to establish connection
+        :param service_name: the keyring service name to be used to store access tokens, default is "nista_library"
+        :param base_url: "https://app.nista.io" if left None
+        :param enable_store_refresh_token: switch storage of refreshtoken on/off, in order to just keep access token for a limited period of time
+        :param client_id: username for an optional login with OAuth2.0 Client/Secret Authentication
+        :param client_secret: secret for an optional login with OAuth2.0 Client/Secret Authentication
+        :param verify_ssl: define if the https connection will be checked for security
+        """
         super().__init__(
             base_url=base_url,
             workspace_id=workspace_id,
